\name{outlierPair}
\alias{outlierPair}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{ A method for detecting single outliers in experimental designs with only two replicates per treatment condition. }
\description{

This function detects pairs of observations with unexpectedly large differences compared to the rest of the data.  Pairs with large differences may include single outlier observations.

}
\usage{
outlierPair(x, INDEX, p = 0.05, na.rm = TRUE)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{x}{A vector of observations. }
  \item{INDEX}{A list of factors, each the same length as x, used to indicate the replicate observations. }
  \item{p}{The significance level at which to perform the test. }
  \item{na.rm}{If TRUE, will remove missing values.}
}
\details{
This outlier detection method is useful for small factorial designs in which the usual residuals from a linear model would have a large number of linear dependencies compared to the actual number of residuals.  The function first calculates n difference between 2n replicates (call these pure residuals), and then constructs an F-statistic: f=(large squared p.r.)/((sum of remaining squared p.r.'s)/(n-1)).  An p-value (adjusted for taking the largest of the p.r.'s) is calculated by n*Pr(F(1,n-1)>f). If f>=n-1, this p-value is exact, otherwise it is an upper bound.
}
\value{

  \item{test}{Returns TRUE if an outlier pair is detected at the specified level of significance p.}
  \item{pval}{The actual value of n*Pr(F(1,n-1)>f).}
  \item{whichPair}{The index of the pair of observations with the largest difference.}
}
\references{Scholtens et al.  Analyzing Factorial Designed Microarray Experiments.  Journal of Multivariate Analysis.  To appear. }
\author{Denise Scholtens}
%\note{ }

% ~Make other sections like Warning with \section{Warning }{....} ~

\seealso{\code{\link{madOutPair}} }
\examples{

data(estrogen)

outlierPair(exprs(estrogen)[1,],INDEX=pData(estrogen),p=.05)
outlierPair(exprs(estrogen)[247,],INDEX=pData(estrogen),p=.05)
outlierPair(exprs(estrogen)[495,],INDEX=pData(estrogen),p=.05)







}
\keyword{models }
\keyword{design }
